#
# Copyright (c) 2003 Seth Kingsley.  All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 3. All advertising materials mentioning features or use of this software
#    must display the following acknowledgment:
#    This product includes software developed by Seth Kingsley and
#    contributors.
# 4. Neither the author's name, nor any of the contributors names may be
#    used to endorse or promote products derived from this software without
#    specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
# IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
#   $Id: sk.lib.mk,v 1.9 2004/06/08 00:31:49 sethk Exp $

.ifndef BASE_DIR
.error "$${BASE_DIR} must be defined"
.endif	# !BASE_DIR

SK_MAKE_SYS = true

.include    "${BASE_DIR}/mk/sk.global.mk"

.ifndef OBJS
OBJS = ${SRCS:R:S/$/.o/}
.endif

.ifndef NO_SHARED
SOBJS = ${OBJS:R:S/$/.So/}
.endif NO_SHARED

.SUFFIXES: .So .so

.ifndef NO_STATIC
all: ${LIB}.a

${LIB}.a: ${OBJS}
	${AR} ${ARFLAGS} ${.TARGET} ${.ALLSRC}
	${RANLIB} ${RANLIB_FLAGS} ${.TARGET}
.endif

.ifdef MAJOR
.ifdef MINOR
SO_SUFFIX = .${MAJOR}.${MINOR}
.else
SO_SUFFIX = .${MAJOR}
.endif
.endif

.ifndef NO_SHARED
all: ${LIB}.so${SO_SUFFIX}
.endif NO_SHARED

.c.So:
	${CC} ${CPPFLAGS} ${CFLAGS} ${PICFLAGS} -DPIC -o ${.TARGET}\
	    -c ${.IMPSRC}

.cpp.So:
	${CXX} ${CPPFLAGS} ${CXXFLAGS} ${PICFLAGS} -DPIC -o ${.TARGET}\
	    -c ${.IMPSRC}

${LIB}.so${SO_SUFFIX}: ${SOBJS}
	${CC} ${LDFLAGS} -shared -o ${.TARGET} `lorder ${SOBJS} | tsort -q`\
	    ${LDLIBS}

install:
.ifndef INTERNAL_LIB
.ifndef NO_STATIC
	[ -d ${PREFIX}/${LIB_DIR} ] ||\
	    mkdir -p -m ${DIR_MODE} ${PREFIX}/${LIB_DIR}
	${INSTALL} ${INST_FLAGS} ${STRIP} -o ${LIB_OWN} -g ${LIB_GRP}\
	    -m ${LIB_MODE} ${LIB}.a ${PREFIX}/${LIB_DIR}
.endif
.ifndef NO_SHARED
	[ -d ${PREFIX}/${LIB_DIR} ] ||\
	    mkdir -p -m ${DIR_MODE} ${PREFIX}/${LIB_DIR}
	${INSTALL} ${INST_FLAGS} ${STRIP} -o ${LIB_OWN} -g ${LIB_GRP}\
	    -m ${LIB_MODE} ${LIB}.so${SO_SUFFIX} ${PREFIX}/${LIB_DIR}
.endif
.endif # INTERNAL_LIB

clean::
.ifndef NO_STATIC
	rm -f ${LIB}.a
.endif
.ifndef NO_SHARED
	rm -f ${SOBJS}
	rm -f ${LIB}.so${SO_SUFFIX}
.endif

.include    "${BASE_DIR}/mk/sk.targets.mk"

